<?PHP

function getDirFiles($dir_path, $files_extension) {
	$files_list = array();

	if (is_dir($dir_path)) {
		if ($dh = opendir($dir_path)) {
			while (($file = readdir($dh)) !== false) {
				if (is_file($dir_path.$file) AND preg_match('/^.+\.'.$files_extension.'$/i', $file)) {
					$files_list[] = $file;
				}
			}
			closedir($dh);
		}
	}
	return $files_list;
}

function getDirSubDirs($dir_path) {
	$dirs_list = array();

	if (is_dir($dir_path)) {
		if ($dh = opendir($dir_path)) {
			while (($file = readdir($dh)) !== false) {
				if (is_dir($dir_path.$file) AND $file != '.' AND $file != '..') {
					$dirs_list[] = $file;
				}
			}
			closedir($dh);
		}
	}

	return $dirs_list;
}

function scan_dir($dirPath, $dirURL, $dirName, $thisName='') {
	$files_count = create_playlist($dirPath, $dirURL, $dirName);
	print $dirURL.' - '.$files_count.' files found<br>'."\n";

	$subitems = array();
	$subDirs = getDirSubDirs($dirPath);
	foreach ($subDirs as $subDir) {
		$subitems[] = scan_dir($dirPath.$subDir.'/', $dirURL.rawurlencode($subDir).'/', $dirName.'_'.$subDir, $subDir);
	}

	$has_play_lists = ($files_count > 0 ? true : false);
	if (!$has_play_lists) {
		foreach($subitems as $subitem) {
			if ($subitem['has_play_lists']) {
				$has_play_lists = true;
			};
		};
	};


	if ($thisName != '') {
		return array(
			'name' => $thisName,

			'path' =>$dirPath,
			'url' => $dirURL,
			'xspf' => ($files_count > 0 ? $dirName : ''),
			'subitems' => $subitems,
			'has_play_lists' => $has_play_lists,
		);
	} else {
		return $subitems;
	};
}

function create_playlist($dirPath, $dirURL, $dirName) {
	$play_list = array();

	$files = getDirFiles($dirPath, 'mp3');
	foreach ($files as $file) {
		$name = str_replace('.mp3', '', $file);

		$play_list_item = '';
		$play_list_item .= '<track>'."\n";
		$play_list_item .= "\t".'<location>'.$dirURL.rawurlencode($file).'</location>'."\n";
		$play_list_item .= "\t".'<image>'.$dirURL.'coverart.jpg'.'</image>'."\n";
		$play_list_item .= "\t".'<annotation>'.utf8_encode(htmlspecialchars($name)).'</annotation>'."\n";
		$play_list_item .= '</track>'."\n";

		$play_list[] = $play_list_item;
	}

	$filename = PLAYLIST_DIRECTORY_PATH.'playlist'.$dirName.'.xspf';
	@unlink($filename);

	if (count($play_list)) {
		if ($handle = fopen($filename, 'w')) {
			fwrite($handle, '<?xml version="1.0" encoding="UTF-8"?>'."\n");
			fwrite($handle, '<playlist version="0" xmlns = "http://xspf.org/ns/0/">'."\n");
			fwrite($handle, '<trackList>'."\n");

			fwrite($handle, "\n".join('', $play_list)."\n");

			fwrite($handle, '</trackList>'."\n");
			fwrite($handle, '</playlist>'."\n");

			fclose($handle);
		};
    };

    return count($play_list);
}

?>